@@ -14,17 +14,6 @@ AboutDlg::~AboutDlg()
     delete m_ui;
 }
 
-void AboutDlg::changeEvent(QEvent *e)
-{
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        m_ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
 void AboutDlg::on_creditsButton_clicked()
 {
     CreditsDlg *credits = new CreditsDlg(this);
