@@ -1,7 +1,8 @@
 #include "buttonwidget.h"
 
 ButtonWidget::ButtonWidget(QWidget *parent, const QString &aFilenameUnpressed,const QString &aFileNamePressed,
-                           const QString &aConfFileName, const QString &aButtonText, const QStringList &commands, int time) : QWidget( parent )
+                           const QString &aConfFileName, const QString &aButtonText, const QStringList &commands, int time) :
+        QWidget( parent )
 {
         allowText = false;
         fileNameUnPressed = aFilenameUnpressed;
@@ -15,7 +16,7 @@ ButtonWidget::ButtonWidget(QWidget *parent, const QString &aFilenameUnpressed,co
         textDownWeight = 50;
         textUpColor = QColor(255,255,255);
 
-        if(fileNameUnPressed.contains(themesPath,Qt::CaseInsensitive)) {
+        if(fileNameUnPressed.contains((themesPath),Qt::CaseInsensitive)) {
             fileNameUnPressed = aFilenameUnpressed;
             if(!aFileNamePressed.isNull()) { fileNamePressed = aFileNamePressed; }
             if(!aConfFileName.isNull()) { confFileName = aConfFileName; }
@@ -65,13 +66,13 @@ ButtonWidget::~ButtonWidget()
 
 void ButtonWidget::process_line(QString line)
 {
-    if(line.contains("allow-text=true",Qt::CaseInsensitive))
+    if(line.contains(("allow-text=true"),Qt::CaseInsensitive))
         allowText = true;
 
-    if(line.contains("text-format-up",Qt::CaseInsensitive)) {
+    if(line.contains(("text-format-up"),Qt::CaseInsensitive)) {
         QString lineForeground = line;
 
-        if(line.contains("font_family=",Qt::CaseInsensitive)) {
+        if(line.contains(("font_family="),Qt::CaseInsensitive)) {
             QString tempLine = line;
             int family = tempLine.indexOf("font_family=") + 12;
             tempLine.remove(0,family);
@@ -80,17 +81,17 @@ void ButtonWidget::process_line(QString line)
             tempLine.chop(count - size);
             upFontFamily = tempLine.trimmed();
         }
-        if(line.contains("font_desc=",Qt::CaseInsensitive)) {
+        if(line.contains(("font_desc="),Qt::CaseInsensitive)) {
             QStringList list = line.split(QRegExp("\\b"));
-            if(list.contains("Light",Qt::CaseInsensitive))
+            if(list.contains(("Light"),Qt::CaseInsensitive))
                 textUpWeight = 25;
-            if(list.contains("Normal",Qt::CaseInsensitive))
+            if(list.contains(("Normal"),Qt::CaseInsensitive))
                 textUpWeight = 50;
-            if(list.contains("Bold",Qt::CaseInsensitive))
+            if(list.contains(("Bold"),Qt::CaseInsensitive))
                 textUpWeight = 75;
         }
 
-        if(line.contains("size=",Qt::CaseInsensitive)) {
+        if(line.contains(("size="),Qt::CaseInsensitive)) {
             int i;
             int x;
             int lineLength;
@@ -108,30 +109,29 @@ void ButtonWidget::process_line(QString line)
             textUpSize = line.toInt();
             textUpSize = textUpSize / 1024;
         }
-            if(line.contains("weight=",Qt::CaseInsensitive)) {
-                int i;
-                int x;
-                int lineLength;
-                int chopLength;
-                QString y = "weight=";
-                QString w = "foreground";
-                i = line.indexOf(y);
-                line.remove(0,(i+7));
-                x = line.indexOf(w);
-                lineLength = line.length();
-                chopLength = lineLength - x + 2;
-                line.chop(chopLength);
+        if(line.contains(("weight="),Qt::CaseInsensitive)) {
+            int i;
+            int x;
+            int lineLength;
+            int chopLength;
+            QString y = "weight=";
+            QString w = "foreground";
+            i = line.indexOf(y);
+            line.remove(0,(i+7));
+            x = line.indexOf(w);
+            lineLength = line.length();
+            chopLength = lineLength - x + 2;
+            line.chop(chopLength);
 
+            if(line.contains(("Light"),Qt::CaseInsensitive))
+                textUpWeight = 25;
+            if(line.contains(("Normal"),Qt::CaseInsensitive))
+                textUpWeight = 50;
+            if(line.contains(("Bold"),Qt::CaseInsensitive))
+                textUpWeight = 75;
+        }
 
-                if(line.contains("Light",Qt::CaseInsensitive))
-                    textUpWeight = 25;
-                if(line.contains("Normal",Qt::CaseInsensitive))
-                    textUpWeight = 50;
-                if(line.contains("Bold",Qt::CaseInsensitive))
-                    textUpWeight = 75;
-            }
-
-        if(lineForeground.contains("foreground=",Qt::CaseInsensitive)) {
+        if(lineForeground.contains(("foreground="),Qt::CaseInsensitive)) {
             bool ok;
             QString y = "foreground=";
             iU = lineForeground.indexOf(y);
@@ -145,8 +145,8 @@ void ButtonWidget::process_line(QString line)
         }
     }
 
-    if(line.contains("text-format-down",Qt::CaseInsensitive)) {
-        if(line.contains("font_family=",Qt::CaseInsensitive)) {
+    if(line.contains(("text-format-down"),Qt::CaseInsensitive)) {
+        if(line.contains(("font_family="),Qt::CaseInsensitive)) {
             QString tempLine = line;
             int family = tempLine.indexOf("font_family=") + 12;
             tempLine.remove(0,family);
@@ -155,18 +155,18 @@ void ButtonWidget::process_line(QString line)
             tempLine.chop(count - size);
             downFontFamily = tempLine.trimmed();
         }
-        if(line.contains("font_desc=",Qt::CaseInsensitive)) {
+        if(line.contains(("font_desc="),Qt::CaseInsensitive)) {
         QStringList list = line.split(QRegExp("\\b"));
-        if(list.contains("Light",Qt::CaseInsensitive))
+        if(list.contains(("Light"),Qt::CaseInsensitive))
             textDownWeight = 25;
-        if(list.contains("Normal",Qt::CaseInsensitive))
+        if(list.contains(("Normal"),Qt::CaseInsensitive))
             textDownWeight = 50;
-        if(list.contains("Bold",Qt::CaseInsensitive))
+        if(list.contains(("Bold"),Qt::CaseInsensitive))
             textDownWeight = 75;
         downFontFamily = list.at(0);
         }
 
-        if(line.contains("size=",Qt::CaseInsensitive)) {
+        if(line.contains(("size="),Qt::CaseInsensitive)) {
             int i;
             int x;
             int lineLength;
@@ -183,7 +183,7 @@ void ButtonWidget::process_line(QString line)
             textDownSize = line.toInt();
             textDownSize = textDownSize / 1024;
         }
-        if(line.contains("weight=",Qt::CaseInsensitive)) {
+        if(line.contains(("weight="),Qt::CaseInsensitive)) {
             int i;
             int x;
             int lineLength;
@@ -197,15 +197,15 @@ void ButtonWidget::process_line(QString line)
             chopLength = lineLength - x + 2;
             line.chop(chopLength);
 
-            if(line.contains("Light",Qt::CaseInsensitive))
+            if(line.contains(("Light"),Qt::CaseInsensitive))
                 textDownWeight = 25;
-            if(line.contains("Normal",Qt::CaseInsensitive))
+            if(line.contains(("Normal"),Qt::CaseInsensitive))
                 textDownWeight = 50;
-            if(line.contains("DemiBold",Qt::CaseInsensitive))
+            if(line.contains(("DemiBold"),Qt::CaseInsensitive))
                 textDownWeight = 63;
-            if(line.contains("Bold",Qt::CaseInsensitive))
+            if(line.contains(("Bold"),Qt::CaseInsensitive))
                 textDownWeight = 75;
-            if(line.contains("Black",Qt::CaseInsensitive))
+            if(line.contains(("Black"),Qt::CaseInsensitive))
                 textDownWeight = 87;
         }
     }
@@ -218,7 +218,7 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
         p.begin(this);
         p.save();
         p.drawPixmap(0, 0, unpressedPixmap );
-        if(allowText && !buttonText.contains("blank",Qt::CaseInsensitive)) {
+        if(allowText && !buttonText.contains(("blank"),Qt::CaseInsensitive)) {
             p.setPen(textUpColor);
             p.setFont(textUpFont);
             p.drawText(this->rect(),Qt::AlignCenter,buttonText);
@@ -229,119 +229,119 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
 
 void ButtonWidget::checkButtonCommand()
 {
-        if(fileNameUnPressed.contains("up",Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up" || buttonText == "UP")
+        if(fileNameUnPressed.contains(("up"),Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up" || buttonText == "UP")
         {
             fileNameUnPressed = defaultButtonsPath + "up/unpressed.png";
             fileNamePressed = defaultButtonsPath + "up/pressed.png";
             confFileName = defaultButtonsPath + "up/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("down",Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down" || buttonText == "DOWN")
+        if(fileNameUnPressed.contains(("down"),Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down" || buttonText == "DOWN")
         {
             fileNameUnPressed = defaultButtonsPath + "down/unpressed.png";
             fileNamePressed = defaultButtonsPath + "down/pressed.png";
             confFileName = defaultButtonsPath + "down/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("left",Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left" || buttonText == "LEFT")
+        if(fileNameUnPressed.contains(("left"),Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left" || buttonText == "LEFT")
         {
             fileNameUnPressed = defaultButtonsPath + "left/unpressed.png";
             fileNamePressed = defaultButtonsPath + "left/pressed.png";
             confFileName = defaultButtonsPath + "left/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("right",Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right" || buttonText == "RIGHT")
+        if(fileNameUnPressed.contains(("right"),Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right" || buttonText == "RIGHT")
         {
             fileNameUnPressed = defaultButtonsPath + "right/unpressed.png";
             fileNamePressed = defaultButtonsPath + "right/pressed.png";
             confFileName = defaultButtonsPath + "right/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("next",Qt::CaseInsensitive))
+        if(fileNameUnPressed.contains(("next"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "next/unpressed.png";
             fileNamePressed = defaultButtonsPath + "next/pressed.png";
             confFileName = defaultButtonsPath + "next/button.conf";
             return;
         }
-        if(fileNameUnPressed == "0" || fileNameUnPressed.contains("num_0",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "0" || fileNameUnPressed.contains(("num_0"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_0/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_0/pressed.png";
             confFileName = defaultButtonsPath + "num_0/button.conf";
             return;
         }
-        if(fileNameUnPressed == "1" || fileNameUnPressed.contains("num_1",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "1" || fileNameUnPressed.contains(("num_1"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_1/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_1/pressed.png";
             confFileName = defaultButtonsPath + "num_1/button.conf";
             return;
         }
-        if(fileNameUnPressed == "2" || fileNameUnPressed.contains("num_2",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "2" || fileNameUnPressed.contains(("num_2"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_2/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_2/pressed.png";
             confFileName = defaultButtonsPath + "num_2/button.conf";
             return;
         }
-        if(fileNameUnPressed == "3" || fileNameUnPressed.contains("num_3",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "3" || fileNameUnPressed.contains(("num_3"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_3/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_3/pressed.png";
             confFileName = defaultButtonsPath + "num_3/button.conf";
             return;
         }
-        if(fileNameUnPressed == "4" || fileNameUnPressed.contains("num_4",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "4" || fileNameUnPressed.contains(("num_4"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_4/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_4/pressed.png";
             confFileName = defaultButtonsPath + "num_4/button.conf";
             return;
         }
-        if(fileNameUnPressed == "5" || fileNameUnPressed.contains("num_5",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "5" || fileNameUnPressed.contains(("num_5"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_5/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_5/pressed.png";
             confFileName = defaultButtonsPath + "num_5/button.conf";
             return;
         }
-        if(fileNameUnPressed == "6" || fileNameUnPressed.contains("num_6",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "6" || fileNameUnPressed.contains(("num_6"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_6/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_6/pressed.png";
             confFileName = defaultButtonsPath + "num_6/button.conf";
             return;
         }
-        if(fileNameUnPressed == "7" || fileNameUnPressed.contains("num_7",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "7" || fileNameUnPressed.contains(("num_7"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_7/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_7/pressed.png";
             confFileName = defaultButtonsPath + "num_7/button.conf";
             return;
         }
-        if(fileNameUnPressed == "8" || fileNameUnPressed.contains("num_8",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "8" || fileNameUnPressed.contains(("num_8"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_8/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_8/pressed.png";
             confFileName = defaultButtonsPath + "num_8/button.conf";
             return;
         }
-        if(fileNameUnPressed == "9" || fileNameUnPressed.contains("num_9",Qt::CaseInsensitive))
+        if(fileNameUnPressed == "9" || fileNameUnPressed.contains(("num_9"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "num_9/unpressed.png";
             fileNamePressed = defaultButtonsPath + "num_9/pressed.png";
             confFileName = defaultButtonsPath + "num_9/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("ok",Qt::CaseInsensitive))
+        if(fileNameUnPressed.contains(("ok"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "ok/unpressed.png";
             fileNamePressed = defaultButtonsPath + "ok/pressed.png";
             confFileName = defaultButtonsPath + "ok/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("pause",Qt::CaseInsensitive))
+        if(fileNameUnPressed.contains(("pause"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "pause/unpressed.png";
             fileNamePressed = defaultButtonsPath + "pause/pressed.png";
@@ -355,7 +355,7 @@ void ButtonWidget::checkButtonCommand()
             confFileName = defaultButtonsPath + "right/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("power",Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF" ||
+        if(fileNameUnPressed.contains(("power"),Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF" ||
            fileNameUnPressed == "on/off" || fileNameUnPressed == "On/Off")
         {
             fileNameUnPressed = defaultButtonsPath + "power/unpressed.png";
@@ -363,7 +363,7 @@ void ButtonWidget::checkButtonCommand()
             confFileName = defaultButtonsPath + "power/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("prev",Qt::CaseInsensitive))
+        if(fileNameUnPressed.contains(("prev"),Qt::CaseInsensitive))
         {
             fileNameUnPressed = defaultButtonsPath + "prev/unpressed.png";
             fileNamePressed = defaultButtonsPath + "prev/pressed.png";
