@@ -39,7 +39,7 @@ void CommandChainDlg::getCommands(QListWidgetItem* item)
     QTextStream in(&file);
     while (!in.atEnd()) {
         QString line = in.readLine();
-        if(line.contains("end remote",Qt::CaseInsensitive)) {
+        if(line.contains(("end remote"),Qt::CaseInsensitive)) {
             m_ui->commandlistWidget->clear();
             m_ui->commandlistWidget->insertItems(0,commands);
             m_ui->commandlistWidget->sortItems(Qt::AscendingOrder);
@@ -57,12 +57,12 @@ void CommandChainDlg::commandItemClicked(QListWidgetItem* item)
 }
 void CommandChainDlg::process_line(QString line)
 {
-    if(line.contains("end codes", Qt::CaseInsensitive))
+    if(line.contains(("end codes"), Qt::CaseInsensitive))
            flag = false;
-    if(line.contains("end raw_codes", Qt::CaseInsensitive))
+    if(line.contains(("end raw_codes"), Qt::CaseInsensitive))
            raw_flag = false;
     if(flag) {
-        if(line.contains("0x",Qt::CaseInsensitive)) {
+        if(line.contains(("0x"),Qt::CaseInsensitive)) {
             QString commandName = line;
             int lineLength;
             QString finalCommandName;
@@ -81,15 +81,15 @@ void CommandChainDlg::process_line(QString line)
         }
     }
     if(raw_flag) {
-         if(line.contains("name", Qt::CaseInsensitive)) {
+         if(line.contains(("name"), Qt::CaseInsensitive)) {
             line = line.trimmed();
             line.remove(0,5);
             commands.append(line);
          }
     }
-    if(line.contains("begin codes", Qt::CaseInsensitive))
+    if(line.contains(("begin codes"), Qt::CaseInsensitive))
         flag = true;
-    if(line.contains("begin raw_codes", Qt::CaseInsensitive))
+    if(line.contains(("begin raw_codes"), Qt::CaseInsensitive))
         raw_flag = true;
 }
 void CommandChainDlg::deleteRemote()
@@ -163,7 +163,7 @@ void CommandChainDlg::deleteRemote()
             pathList.append(line);
         }
         for(int i = 0; i<pathList.count();i++) {
-            if(pathList.at(i).contains(remoteName))
+            if(pathList.at(i).contains((remoteName),Qt::CaseInsensitive))
             pathList.removeAt(i);
         }
         LircPathFile.close();
@@ -196,7 +196,7 @@ void CommandChainDlg::on_downloadRemoteButton_clicked()
 
 void CommandChainDlg::read_line(QString line, int readIndex)
 {
-    if(line.contains("LircConfs:", Qt::CaseInsensitive))
+    if(line.contains(("LircConfs:"), Qt::CaseInsensitive))
         {
             line.remove(0,11);
             line.append(" ");
