@@ -87,7 +87,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             for(int i= 0; i< sList.count();i++) { // Streams only one remote data to file
                 QString line = sList.at(i);
                 out << line; // Original version had only this line.
-                if(line.contains("end remote",Qt::CaseInsensitive))
+                if(line.contains(("end remote"),Qt::CaseInsensitive))
                     break;
             }
             deviceFile.close();
@@ -142,8 +142,8 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             for(int j = 0; j<sList.count();j++) {
                 lastLine =  sList.at(j);
 
-                if (lastLine.contains("end", Qt::CaseInsensitive))
-                    if(!deviceList.contains(modelItem,Qt::CaseInsensitive)) {
+                if (lastLine.contains(("end"), Qt::CaseInsensitive))
+                    if(!deviceList.contains((modelItem),Qt::CaseInsensitive)) {
                        deviceList.append("include \"" + devicesPath + modelItem + "\"");
 
                     for(int i= 0; i< deviceList.count();i++) {
@@ -163,7 +163,7 @@ void DownloadRemoteDlg::processReturnValue(int Id,QVariant data)
             while(!stream.atEnd())
             {
                 QString line = stream.readLine();
-                if(line.contains(para,Qt::CaseInsensitive))
+                if(line.contains((para),Qt::CaseInsensitive))
                     lircExists = true;
             }
             if(!lircExists)
