@@ -21,9 +21,6 @@ public:
     //! Boolean for telling if downloading from RemoteStartupDlg or CommandChainDlg.
     bool remoteStartup;
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::DownloadRemoteDlg *m_ui;
     //! Object for PHP calls.
@@ -57,9 +54,9 @@ private slots:
     //! Slot to get remote lirc file.
     void getFile();
     //! Emits button properties to QtIrreco class which emits them to LayoutWidget.
-    void AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList aCommand, int number);
+    void addButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList aCommand, int number);
     //! Slot for emitting remote name to LayoutWidget.
-    void enableRemoteNameAdding(const QString &remoteName);
+    void enableRemoteNameAdding(QString remoteName);
     //! Slot for emitting clear signal.
     void clearScreenForNewRemote();
 
