@@ -95,7 +95,7 @@ void LayoutWidget::mousePressEvent(QMouseEvent *event)
         p.begin(&copyButton->pressedPixmap);
         p.save();
         p.drawPixmap(0, 0, copyButton->pressedPixmap );
-        if(copyButton->allowText && !copyButton->buttonText.contains("blank",Qt::CaseInsensitive)) {
+        if(copyButton->allowText && !copyButton->buttonText.contains(("blank"),Qt::CaseInsensitive)) {
             p.setPen(copyButton->textUpColor);
             p.setFont(copyButton->textUpFont);
             p.drawText(copyButton->rect(),Qt::AlignCenter,copyButton->buttonText);
@@ -329,19 +329,19 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
         bgTheme = bgTheme.remove(0,26);
         int slashIndex = bgTheme.indexOf(QChar('/'));
         bgTheme.remove(slashIndex,bgTheme.count()-slashIndex);
-        if(!themesUsed.contains(bgTheme))
+        if(!themesUsed.contains((bgTheme),Qt::CaseInsensitive))
            themesUsed.append(bgTheme);
      }
 
     for( int i=0 ; i<vector->count() ; i++ ) {
         QString themeName;
         QString temp = vector->at(i)->fileNameUnPressed;
-        if(!temp.contains("/opt/qtirreco/defaulttheme")) {
+        if(!temp.contains(("/opt/qtirreco/defaulttheme"),Qt::CaseInsensitive)) {
             temp = temp.remove(0,26);
             int slashIndex = temp.indexOf(QChar('/'));
             temp.remove(slashIndex,temp.count()-slashIndex);
             themeName = temp;
-            if(!themesUsed.contains(themeName))
+            if(!themesUsed.contains((themeName),Qt::CaseInsensitive))
                 themesUsed.append(themeName);
         }
     }
@@ -353,7 +353,7 @@ void LayoutWidget::addButton(QString fileNameUnPressed, QString fileNamePressed,
         QString version;
         while (!in.atEnd()) {
             version = in.readLine();
-            if(version.contains("version=")) {
+            if(version.contains(("version="),Qt::CaseInsensitive)) {
                 version = version.remove(0,8);
                 themeVersionsUsed.append(version);
             }
