@@ -31,7 +31,7 @@ private:
 
 private slots:
     //! Trys to login database.
-    void on_okPushButton_2_clicked();
+    void on_okPushButton_clicked();
     //! Opens register dialog.
     void on_registerPushButton_clicked();
     //! Slots for clients return value.
