@@ -63,10 +63,10 @@ void QtIrreco::changeOldRemoteButtonPaths(QString fileName) // CAN BE DELETED LA
     QTextStream in(&file);
     QString data = in.readAll();
 
-    if(data.contains("/home/user/.qtirreco/themes/default",Qt::CaseInsensitive))
+    if(data.contains(("/home/user/.qtirreco/themes/default"),Qt::CaseInsensitive))
         data.replace("/home/user/.qtirreco/themes/default","/home/opt/qtirreco/defaulttheme");
 
-    if(data.contains("/home/user/MyDocs/qtirreco/.themes",Qt::CaseInsensitive))
+    if(data.contains(("/home/user/MyDocs/qtirreco/.themes"),Qt::CaseInsensitive))
         data.replace("/home/user/MyDocs/qtirreco/.themes","/home/opt/qtirreco/themes");
 
     file.remove();
@@ -449,7 +449,7 @@ void QtIrreco::saveRemote()
     while (!stream.atEnd()) {
         QString line = stream.readLine();
 
-        if(line.contains("command: ",Qt::CaseInsensitive)) {
+        if(line.contains(("command: "),Qt::CaseInsensitive)) {
             line = line.trimmed();
             line.remove(0,9);
             QString string;
@@ -481,7 +481,7 @@ void QtIrreco::saveRemote()
                     if(line.at(j).isSpace())
                         line.remove(0,j+1);
                 }
-                if(!lircFilePaths.contains(line))
+                if(!lircFilePaths.contains((line),Qt::CaseInsensitive))
                     lircFilePaths.append(line);
             }
         }
@@ -540,25 +540,25 @@ void QtIrreco::showRemote()
 
 void QtIrreco::readRemoteFile(QString line, bool lastLine)
 {
-    if(line.contains("Background: ",Qt::CaseInsensitive)) {
+    if(line.contains(("Background: "),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,12);
-        if(line.contains("default"),Qt::CaseInsensitive)
+        if(line.contains(("default"),Qt::CaseInsensitive))
             backgroundMode = defaultBackground;
-        if(line.contains("theme"),Qt::CaseInsensitive)
+        else if(line.contains(("theme"),Qt::CaseInsensitive))
             backgroundMode = backgroundFromTheme;
-        if(line.contains("image"),Qt::CaseInsensitive)
+        else if(line.contains(("image"),Qt::CaseInsensitive))
             backgroundMode = backgroundFromImage;
-        if(line.contains("color"),Qt::CaseInsensitive)
+        else if(line.contains(("color"),Qt::CaseInsensitive))
             backgroundMode = backgroundFromColor;
 
         lw->setBackgroundMode(backgroundMode);
     }
-    if(line.contains("Image: ",Qt::CaseInsensitive)) {
+    if(line.contains(("Image: "),Qt::CaseInsensitive)) {
         line = line.trimmed();
         backgroundName = line.remove(0,7);
     }
-    if(line.contains("Color:",Qt::CaseInsensitive)) {
+    if(line.contains(("Color:"),Qt::CaseInsensitive)) {
         QString str[3];
 
         line = line.trimmed();
@@ -578,27 +578,27 @@ void QtIrreco::readRemoteFile(QString line, bool lastLine)
         blue = str[2];
     }
      // Button reading
-    if(line.contains("Button:",Qt::CaseInsensitive)) {
+    if(line.contains(("Button:"),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,8);
         buttonText = line;
     }
-    if(line.contains("fileNameUnPressed:",Qt::CaseInsensitive)) {
+    if(line.contains(("fileNameUnPressed:"),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,19);
         fileNameUnPressed = line;
     }
-    if(line.contains("fileNamePressed:",Qt::CaseInsensitive)) {
+    if(line.contains(("fileNamePressed:"),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,17);
         fileNamePressed = line;
     }
-    if(line.contains("confFileName:",Qt::CaseInsensitive)) {
+    if(line.contains(("confFileName:"),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,14);
         confFileName = line;
     }
-    if(line.contains("position:",Qt::CaseInsensitive)) {
+    if(line.contains(("position:"),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,10);
         int index;
@@ -608,20 +608,20 @@ void QtIrreco::readRemoteFile(QString line, bool lastLine)
         xPosition = line.left(index);
         yPosition = line.right(lineLength - (index+1));
     }
-     if(line.contains("timeout: ",Qt::CaseInsensitive)) {
+     if(line.contains(("timeout: "),Qt::CaseInsensitive)) {
         timeOut = 1000;
         line = line.trimmed();
         line.remove(0,9);
         bool ok;
         timeOut = line.toInt(&ok);
     }
-    if(line.contains("command: ",Qt::CaseInsensitive)) {
+    if(line.contains(("command: "),Qt::CaseInsensitive)) {
         line = line.trimmed();
         line.remove(0,9);
         commandChain.append(line);
 
     }
-    if(line.contains("end commandChain",Qt::CaseInsensitive)) {
+    if(line.contains(("end commandChain"),Qt::CaseInsensitive)) {
         int x,y;
         bool ok;
         x = xPosition.toInt(&ok,10);
@@ -649,12 +649,12 @@ void QtIrreco::process_line(QString line)
 {
     line = line.trimmed();
 
-    if(line.contains("current remote",Qt::CaseInsensitive)) {
+    if(line.contains(("current remote"),Qt::CaseInsensitive)) {
           line.chop(17);
           activeRemote = line;
           activeRemote.chop(5);
     }
-    if(line.contains("filename of remote",Qt::CaseInsensitive)) {
+    if(line.contains(("filename of remote"),Qt::CaseInsensitive)) {
         line.chop(21);
         remoteNames->append(line);
     }
@@ -851,7 +851,7 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         QTextStream in(&file);
         while (!in.atEnd()) {
             QString line = in.readLine();
-            if(line.contains("Themes: ",Qt::CaseInsensitive)) {
+            if(line.contains(("Themes: "),Qt::CaseInsensitive)) {
                 line.remove(0,8);
                 for(int i=0;i<line.length();i++) {
                     if(!line.at(i).isSpace())
@@ -864,7 +864,7 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
                 }
 
             }
-            if(line.contains("Theme versions: ",Qt::CaseInsensitive)) {
+            if(line.contains(("Theme versions: "),Qt::CaseInsensitive)) {
                 line.remove(0,16);
                 for(int i=0;i<line.length();i++) {
                     if(line.at(i) != '/')
@@ -965,7 +965,7 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
     QTextStream in(&file);
     while (!in.atEnd()) {
         QString line = in.readLine();
-        if(line.contains("LircPaths: ",Qt::CaseInsensitive)) {
+        if(line.contains(("LircPaths: "),Qt::CaseInsensitive)) {
             line.remove(0,11);
             for(int i=0;i<line.length();i++) {
                 if(!line.at(i).isSpace()) {
@@ -977,7 +977,7 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
                 }
             }
         }
-        if(line.contains("LircConfs: ",Qt::CaseInsensitive)) {
+        if(line.contains(("LircConfs: "),Qt::CaseInsensitive)) {
             line.remove(0,11);
             for(int i=0;i<line.length();i++) {
                 if(!line.at(i).isSpace())
@@ -1191,8 +1191,8 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             for(int j = 0; j<sList.count();j++) {
                 lastLine =  sList.at(j);
 
-                if (lastLine.contains("end", Qt::CaseInsensitive)) {
-                    if(!deviceList.contains(lircConfs.at(callCounter-1),Qt::CaseInsensitive))
+                if (lastLine.contains(("end"), Qt::CaseInsensitive)) {
+                    if(!deviceList.contains((lircConfs.at(callCounter-1)),Qt::CaseInsensitive))
                        deviceList.append("include \"" + devicesPath + lircConfs.at(callCounter-1) + "\"");
 
                     for(int i= 0; i< deviceList.count();i++)
