@@ -45,8 +45,8 @@ void RegisterDlg::changeEvent(QEvent *e)
 void RegisterDlg::on_registerPushButton_clicked()
 {
     // TÄHÄN PITÄÄ KEKSIÄ JOKU JÄRKEVÄ KEINO!!!!
-    if(m_ui->lineEdit->text().contains("/", Qt::CaseInsensitive) || m_ui->lineEdit->text().contains("'", Qt::CaseInsensitive)  ||
-    m_ui->lineEdit->text().contains("*", Qt::CaseInsensitive) || m_ui->lineEdit->text().contains(" ", Qt::CaseInsensitive) ) {
+    if(m_ui->lineEdit->text().contains(("/"), Qt::CaseInsensitive) || m_ui->lineEdit->text().contains(("'"), Qt::CaseInsensitive)  ||
+    m_ui->lineEdit->text().contains(("*"), Qt::CaseInsensitive) || m_ui->lineEdit->text().contains((" "), Qt::CaseInsensitive) ) {
         QMessageBox::warning(this,"Username error ","Username cannot contain special letters like / * ' or space.",
                      QMessageBox::NoButton,QMessageBox::NoButton);
         return;
