@@ -42,12 +42,12 @@ void RemoteStartupDlg::changeEvent(QEvent *e)
 void RemoteStartupDlg::process_line(QString line)
 {
     if(!line.startsWith("#",Qt::CaseInsensitive)) {
-        if(line.contains("end codes", Qt::CaseInsensitive)) {
+        if(line.contains(("end codes"), Qt::CaseInsensitive)) {
                flag = false;
                this->makeButtons();
             }
 
-        if(line.contains("end raw_codes", Qt::CaseInsensitive)) {
+        if(line.contains(("end raw_codes"), Qt::CaseInsensitive)) {
                flag = false;
                this->makeButtons();
             }
@@ -69,16 +69,16 @@ void RemoteStartupDlg::process_line(QString line)
             buttonNames.append(finalButtonName);
         }
         if(raw_flag) {
-             if(line.contains("name", Qt::CaseInsensitive)) {
+             if(line.contains(("name"), Qt::CaseInsensitive)) {
                 line = line.trimmed();
                 line.remove(0,5);
                 buttonNames.append(line);
              }
         }
-        if(line.contains("begin codes", Qt::CaseInsensitive))
+        if(line.contains(("begin codes"), Qt::CaseInsensitive))
             flag = true;
 
-        if(line.contains("begin raw_codes", Qt::CaseInsensitive))
+        if(line.contains(("begin raw_codes"), Qt::CaseInsensitive))
             raw_flag = true;
 
     }
