@@ -99,7 +99,7 @@ void ThemeManager::updateListWidget(QListWidgetItem *item)
         m_ui->versionComboBox->clear();
         for(int i=0;i<deviceThemeCount;i++)
         {
-            if(item->text().contains(themeDirList.at(i),Qt::CaseInsensitive))
+            if(item->text().contains((themeDirList.at(i)),Qt::CaseInsensitive))
             {
                 QFile file(themesPath+themeDirList.at(i)+"/theme.conf");
                 tName = themeDirList.at(i);
@@ -363,7 +363,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
     else if (Id == themeBgIds)
     {
         dbBackgroundIdsList = sList;
-        if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0"))
+        if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains(("0"),Qt::CaseInsensitive))
         {
             this->setWindowTitle("Downloading theme backgrounds...");
             this->getThemeBackgroundsByIds();
@@ -674,7 +674,7 @@ void ThemeManager::on_downloadPushButton_clicked()
 }
 QString ThemeManager::readVersion(QString line)
 {
-        if(line.contains("version=", Qt::CaseInsensitive))
+        if(line.contains(("version="), Qt::CaseInsensitive))
         {
             QString version = line.remove(0,8);
             versionFound = true;
@@ -802,7 +802,7 @@ void ThemeManager::loadThemes()
 }
 void ThemeManager::process_line(QString line)
 {
-        if(line.contains("name=", Qt::CaseInsensitive))
+        if(line.contains(("name="), Qt::CaseInsensitive))
         {
             QString x = line;
             int count;
@@ -814,25 +814,25 @@ void ThemeManager::process_line(QString line)
 }
 void ThemeManager::readThemeConf(QString line)
 {
-        if(line.contains("name=", Qt::CaseInsensitive))
+        if(line.contains(("name="), Qt::CaseInsensitive))
             {
                 m_ui->nameLabel->setText(line.remove(0,5));
                 uploadThemeName = line;
             }
-        if(line.contains("author=", Qt::CaseInsensitive))
+        if(line.contains(("author="), Qt::CaseInsensitive))
             {
                 m_ui->authorLabel->setText(line.remove(0,7));
             }
-        if(line.contains("comments=", Qt::CaseInsensitive))
+        if(line.contains(("comments="), Qt::CaseInsensitive))
             {
                 m_ui->commentTextEdit->setText(line.remove(0,9));
                 uploadComments = line;
             }
-        if(line.contains("version=", Qt::CaseInsensitive))
+        if(line.contains(("version="), Qt::CaseInsensitive))
             {
                 m_ui->versionComboBox->insertItem(0,line.remove(0,8));
             }
-        if(line.contains("preview_button=", Qt::CaseInsensitive))
+        if(line.contains(("preview_button="), Qt::CaseInsensitive))
             {
                 QString button = line.remove(0,15);
                 button.replace(QChar(' '),QString("_"),Qt::CaseInsensitive); // If line contains space replace with _
@@ -842,7 +842,7 @@ void ThemeManager::readThemeConf(QString line)
                 m_ui->pictureLabel->setPalette(palette);
                 m_ui->pictureLabel->setAutoFillBackground(true);
             }
-        if(line.contains("source=own", Qt::CaseInsensitive)) // If theme not yet uploaded
+        if(line.contains(("source=own"), Qt::CaseInsensitive)) // If theme not yet uploaded
             {
                 m_ui->downloadPushButton->setEnabled(true);
                 ownTheme = true;
@@ -899,7 +899,7 @@ void ThemeManager::on_deletePushButton_clicked()
 
     for(int i=0;i<remoteFiles.count();i++) {
        QString fileName = remoteFiles.at(i);
-       if(fileName.contains("remotes.conf",Qt::CaseInsensitive) || fileName.contains("~",Qt::CaseInsensitive))
+       if(fileName.contains(("remotes.conf"),Qt::CaseInsensitive) || fileName.contains(("~"),Qt::CaseInsensitive))
            remoteFiles.removeAt(i);
     }
 
@@ -912,14 +912,14 @@ void ThemeManager::on_deletePushButton_clicked()
                QString line = in.readLine();
                this->readUsedThemes(line);
            }
-        if(usedThemesByRemote.contains(themeToDelete,Qt::CaseInsensitive))
+        if(usedThemesByRemote.contains((themeToDelete),Qt::CaseInsensitive))
             remoteNamesUsingThemeToBeDeleted.append(remoteFiles.at(i));
         usedThemesByRemote.clear();
         file.close();
     }
 
 
-    if(usedThemes.contains(themeToDelete,Qt::CaseInsensitive)) {
+    if(usedThemes.contains((themeToDelete),Qt::CaseInsensitive)) {
 
         themeUsedInRemote = true;
         QString remoteNames;
@@ -958,7 +958,7 @@ void ThemeManager::on_deletePushButton_clicked()
 void ThemeManager::readUsedThemes(QString line)
 {
     QString themeTemp;
-    if(line.contains("Themes: ",Qt::CaseInsensitive)) {
+    if(line.contains(("Themes: "),Qt::CaseInsensitive)) {
         line.remove(0,8);
         //line.append(' ');
         for(int i=0;i<line.length();i++) {
@@ -967,7 +967,7 @@ void ThemeManager::readUsedThemes(QString line)
 
             else {
                 usedThemesByRemote.append(themeTemp);
-                if(!usedThemes.contains(themeTemp,Qt::CaseInsensitive)) {
+                if(!usedThemes.contains((themeTemp),Qt::CaseInsensitive)) {
                     usedThemes.append(themeTemp);
 
                 }
@@ -1338,11 +1338,11 @@ void ThemeManager::uploadThemeBg()
 }
 void ThemeManager::readButtonConf(QString line)
 {
-      if(line.contains("name=", Qt::CaseInsensitive))
+      if(line.contains(("name="), Qt::CaseInsensitive))
          {
              uploadButtonName = line.remove(0,5);
          }
-      if(line.contains("allow-text=", Qt::CaseInsensitive))
+      if(line.contains(("allow-text="), Qt::CaseInsensitive))
          {
              line = line.remove(0,11);
              if(line == "true")
@@ -1354,18 +1354,18 @@ void ThemeManager::readButtonConf(QString line)
                  uploadAllowText = false;
              }
          }
-      if(line.contains("text-format-up=", Qt::CaseInsensitive))
+      if(line.contains(("text-format-up="), Qt::CaseInsensitive))
          {
              uploadTextFormatUp = line.remove(0,15);
          }
-      if(line.contains("text-format-down=", Qt::CaseInsensitive))
+      if(line.contains(("text-format-down="), Qt::CaseInsensitive))
          {
               uploadTextFormatDown = line.remove(0,17);
          }
 }
 void ThemeManager::readBgConf(QString line)
 {
-      if(line.contains("name=", Qt::CaseInsensitive))
+      if(line.contains(("name="), Qt::CaseInsensitive))
          {
              uploadBgName = line.remove(0,5);
          }
